![react-taggy](./images/reacttaggy.jpg "React Taggy")
![action shot](./images/actionshot.jpg "Action Shot")

#### A simple zero-dependency React component for displaying user-defined entities within a block of text.

## Install

`npm i --save react-taggy` or `yarn add react-taggy`

## Basic Usage

#### ES6
`import Taggy from 'react-taggy'`

#### Node Modules
`const Taggy = require('react-taggy').default`

#### Required Props
- `text`: (string || array) The text that will be displayed. May be a string, or an array of tokens.
- `spans`: (array) The locations within the text that will get tagged. If `text` is a string, then `start` and `end` must be provided and refer to character indices. If `text` is an array of tokens, then `index` must be provided and refers to token index. *Note that multi-word entities are handled slightly differently depending on which method you choose. See examples below.*
- `ents`: (array) The allowable entity types and the color of each unique tag type.

#### Example usage where `text` is a string
```javascript
<Taggy text={text} spans={spans} ents={ents} />

const text = 'Michael Jordan ate lunch yesterday in Chicago.'

const spans = [
    {start: 0, end: 14, type: 'PERSON'},
    {start: 25, end: 34, type: 'DATE'},
    {start: 38, end: 45, type: 'LOCATION'}
]

const ents = [
    {type: 'person', color: {r: 166, g: 226, b: 45}},
    {type: 'location', color: {r: 67, g: 198, b: 252}},
    {type: 'date', color: {r: 47, g: 187, b: 171}}
]
```

#### Example usage where `text` is an array
```javascript
<Taggy text={text} spans={spans} ents={ents} />

const text = ['Michael', 'Jordan', 'ate', 'lunch', 'yesterday', 'in', 'Chicago', '.']

const spans = [
  {type: 'person', index: 0},
  {type: 'person', index: 1},
  {type: 'date', index: 4},
  {type: 'location', index: 6}
]

const ents = [
    {type: 'person', color: {r: 166, g: 226, b: 45}},
    {type: 'location', color: {r: 67, g: 198, b: 252}},
    {type: 'date', color: {r: 47, g: 187, b: 171}}
]
```

## Inspiration

This project is originally a fork of [displacy-ent](https://github.com/explosion/displacy-ent) by the guys over at [ExplosionAI](https://explosion.ai/). Now with 100% more React awesomeness!

## License

*react-taggy* is available under BSD. See LICENSE for more details.
